
# Wiener Netze Smartmeter
This module displays data from the smartmeter network of Wiener Netze (Vienna).


## Usage
```
define my_consumption fhempy wienernetze_smartmeter USERNAME PASSWORD
```

USERNAME: Log.wien username
PASSWORD: Log.wien password